==> apache-cxf-3.4.7-src.tar.gz: apache-cxf-3.4.7-src/systests/jaxrs/src/test/java/org/apache/cxf/systest/jaxrs/BookStoreStorage.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.cxf.systest.jaxrs;

import java.util.HashMap;
import java.util.Map;

import javax.annotation.PostConstruct;
import javax.annotation.PreDestroy;
import javax.ws.rs.Path;

@Path("/bookstorestorage/")
public abstract class BookStoreStorage implements LifecycleInterface {
    protected Map<Long, Book> books = new HashMap<>();
    protected long bookId = 123;
    protected int postConstructCalls;
    protected int preDestroyCalls;

    @PostConstruct
    public void postConstruct() {
        if (postConstructCalls++ == 1) {
            throw new RuntimeException();
        }
    }

    @PreDestroy
    public void preDestroy() {
        if (preDestroyCalls++ == 1) {
            throw new RuntimeException();
        }
    }

    protected void checkPostConstruct() {
        if (postConstructCalls != 1) {
            throw new RuntimeException();
        }
    }
}

==> apache-cxf-4.0.7-src.tar.gz: apache-cxf-4.0.7-src/systests/jaxrs/src/test/java/org/apache/cxf/systest/jaxrs/BookStoreStorage.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.cxf.systest.jaxrs;

import java.util.HashMap;
import java.util.Map;

import jakarta.annotation.PostConstruct;
import jakarta.annotation.PreDestroy;
import jakarta.ws.rs.Path;

@Path("/bookstorestorage/")
public abstract class BookStoreStorage implements LifecycleInterface {
    protected Map<Long, Book> books = new HashMap<>();
    protected long bookId = 123;
    protected int postConstructCalls;
    protected int preDestroyCalls;

    @PostConstruct
    public void postConstruct() {
        if (postConstructCalls++ == 1) {
            throw new RuntimeException();
        }
    }

    @PreDestroy
    public void preDestroy() {
        if (preDestroyCalls++ == 1) {
            throw new RuntimeException();
        }
    }

    protected void checkPostConstruct() {
        if (postConstructCalls != 1) {
            throw new RuntimeException();
        }
    }
}
